@@ -11,7 +11,7 @@ use Geo::ShapeFile::Shape::Index;
 
 use parent qw /Geo::ShapeFile/;
 
-our $VERSION = '2.55_001';
+our $VERSION = '2.57_001';
 
 my $little_endian_sys = unpack 'b', (pack 'S', 1 );
 
@@ -640,10 +640,10 @@ sub build_spatial_index {
 
         if (@parts > 1) {
             my %bounds = $self->_get_part_bounds ($part_id);
-            ($x_min, $x_max, $y_min, $y_max) = @bounds{qw /x_min x_max y_min y_max/};
+            ($x_min, $y_min, $x_max, $y_max) = @bounds{qw /x_min y_min x_max y_max/};
         }
         else {
-            ($x_min, $x_max, $y_min, $y_max) = $self->bounds;  #  faster than searching all points
+            ($x_min, $y_min, $x_max, $y_max) = $self->bounds;  #  faster than searching all points
         }
 
         my $n_boxes = @$segments > 20 ? $n : 1;
@@ -857,7 +857,7 @@ Geo::ShapeFile::Shape - Geo::ShapeFile utility class.
 
 =head1 ABSTRACT
 
-  This is a utility class for L<Geo::ShapeFile> that represents shapes.
+  This is a utility class for Geo::ShapeFile that represents shapes.
 
 =head1 DESCRIPTION
 
